@@ -194,3 +194,7 @@ USE_SERVICE_ROLE_DEFAULT = False
 
 MANIFEST_STATUS_FIELD_NAME = "status"
 MANIFEST_STATUS_FIELD_VALUE_IGNORED = "ignored"
+
+
+CONFIG_SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS = "should_delete_rollback_complete_stacks"
+CONFIG_SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS_DEFAULT = False
